@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 my %PropertyAlias = (
     'content-type'  => 'type',
@@ -114,8 +114,8 @@ sub redirect {
 sub finalize {
     my $self = shift;
     my $query = $self->query;
-    my $headers = $query->header( $self->{header} );
-    $query->print( $headers ) unless $headers eq q{};
+    my $header = $self->{header};
+    $query->print( $query->header($header) );
     return;
 }
 
@@ -164,7 +164,7 @@ CGI::Header - Handle CGI.pm-compatible HTTP header properties
 
 =head1 VERSION
 
-This document refers to CGI::Header version 0.56.
+This document refers to CGI::Header version 0.57.
 
 =head1 DEPENDENCIES
 
@@ -668,7 +668,7 @@ Ryo Anazawa (anazawa@cpan.org)
 
 =head1 LICENSE
 
-This module is free software; you can redistibute it and/or
+This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
 =cut
